<?php
/**
 * @package			No Boss Extensions
 * @subpackage  	No Boss Library
 * @author			No Boss Technology <contact@nobosstechnology.com>
 * @copyright		Copyright (C) 2024 No Boss Technology. All rights reserved.
 * @license			GNU Lesser General Public License version 3 or later; see <https://www.gnu.org/licenses/lgpl-3.0.en.html>
 */

namespace Noboss\Library\Component;

use Joomla\CMS\MVC\Controller\FormController;
use Joomla\CMS\Versioning\VersionableControllerTrait;

// phpcs:disable PSR1.Files.SideEffects
\defined('_JEXEC') or die;
// phpcs:enable PSR1.Files.SideEffects

/**
 *  Classe a ser estendida em componentes para controller de edicao de registros
 *  @author  Johnny Salazar Reidel
 * 
 *  Observacao: o funcionamento desta classe tem como requisito que o componente seja desenvolvido no modelo No Boss
 */
class NbControllerEditComponent extends FormController{
    use VersionableControllerTrait;
    
    /**
     * Metodo para verificar se voce pode adicionar um novo registro.
     *
     * @param   array  $data  Uma matriz de dados de entrada.
     *
     * @return  boolean
     */
    protected function allowAdd($data = []){
        return $this->app->getIdentity()->authorise('core.create', $this->input->get('option'));
    }

    /**
     * Metodo para executar operacoes em lote.
     *
     * @param   object  $model  The model.
     *
     * @return  boolean  Verdadeiro se for bem-sucedido, falso caso contrario e se o erro interno for definido.
     */
    public function batch($model = null){
        $this->checkToken();

        // Set the model
        $model = $this->getModel($this->editView);

        // Preset the redirect
        $this->setRedirect('index.php?option='.$this->input->get('option').'&view='.$this->listView);

        return parent::batch($model);
    }
}
?>
